@@ -203,30 +203,40 @@ class FilterInput(ipw.HBox):
 class FilterInputParser:
     """Parse user input for filters"""
 
-    def __default__(self, value: Any) -> Any:  # pylint: disable=no-self-use
-        """Default parsing fallback function"""
-        return value, None
-
-    def parse(self, key: str, value: Any) -> Any:
+    def parse(self, key: str, value: Any) -> Tuple[Any, Union[None, str]]:
         """Reroute to self.<key>(value)"""
-        if isinstance(value, str):
-            # Remove any superfluous whitespace at the beginning and end of string values
-            value = value.strip()
-
         func = getattr(self, key, None)
         if func is None:
             return self.__default__(value)
         return func(value)
 
     @staticmethod
-    def chemical_formula_descriptive(value: str) -> str:
-        """Chemical formula descriptive is a free form input"""
+    def __default__(value: Any) -> Tuple[Any, None]:
+        """Default parsing fallback function"""
+        return value, None
+
+    @staticmethod
+    def default_string_filter(value: str) -> Tuple[str, None]:
+        """Default handling of string filters
+
+        Remove any superfluous whitespace at the beginning and end of string values.
+        Remove embedded `"` and wrap the value in `"` (if the value is supplied).
+        """
+        value = value.strip()
         value = value.replace('"', "")
         res = f'"{value}"' if value else ""
         return res, None
 
+    def id(self, value: str) -> Tuple[str, None]:  # pylint: disable=invalid-name
+        """id is a string input"""
+        return self.default_string_filter(value)
+
+    def chemical_formula_descriptive(self, value: str) -> Tuple[str, None]:
+        """Chemical formula descriptive is a free form input"""
+        return self.default_string_filter(value)
+
     @staticmethod
-    def nperiodic_dimensions(value: List[bool]) -> List[int]:
+    def nperiodic_dimensions(value: List[bool]) -> Tuple[List[int], None]:
         """Return list of nperiodic_dimensions values according to checkbox choices"""
         res = []
         for include, periodicity in zip(value, range(4)):
@@ -274,7 +284,7 @@ class FilterInputParser:
     @staticmethod
     def elements(
         value: Tuple[bool, Dict[str, int]]
-    ) -> Tuple[Union[List[str], List[Tuple[str]]], bool]:
+    ) -> Tuple[Union[List[str], List[Tuple[str]]], List[str]]:
         """Extract included and excluded elements"""
         use_all = value[0]
         ptable_value = value[1]
@@ -296,21 +306,24 @@ class FilterInputParser:
             exclude,
         )
 
-        res = []
+        values = []
+        operators = []
         if exclude:
             elements = ",".join([f'"{element}"' for element in exclude])
-            res.append(("NOT", elements))
+            values.append(("NOT", elements))
+            operators.append(" HAS ANY ")
         if include:
             include_elements = ",".join([f'"{element}"' for element in include])
-            res.append(include_elements)
-
-        operator = " HAS ALL " if use_all else " HAS ANY "
+            values.append(include_elements)
+            operators.append(" HAS ALL " if use_all else " HAS ANY ")
 
         LOGGER.debug(
-            "elements: Resulting parsed operator: %r and value: %r", operator, res
+            "elements: Resulting parsed operator(s): %r and value(s): %r",
+            operators,
+            values,
         )
 
-        return res, operator
+        return values, operators
 
 
 class FilterInputs(FilterTabSection):
@@ -528,14 +541,24 @@ class FilterInputs(FilterTabSection):
                 parsed_operator = self.OPERATOR_MAP.get(field, "")
 
             if isinstance(parsed_value, (list, tuple, set)):
-                for value in parsed_value:
+                for index, value in enumerate(parsed_value):
                     inverse = ""
                     if isinstance(value, tuple) and value[0] == "NOT":
                         inverse = "NOT "
                         value = value[1]
-                    result.append(f"{inverse}{field}{parsed_operator}{value}")
+                    operator = (
+                        parsed_operator[index]
+                        if isinstance(parsed_operator, (list, tuple, set))
+                        else parsed_operator
+                    )
+                    result.append(f"{inverse}{field}{operator}{value}")
             elif isinstance(parsed_value, str):
-                result.append(f"{field}{parsed_operator}{parsed_value}")
+                operator = (
+                    parsed_operator[0]
+                    if isinstance(parsed_operator, (list, tuple, set))
+                    else parsed_operator
+                )
+                result.append(f"{field}{operator}{parsed_value}")
             else:
                 raise ParserError(
                     field=field,
