@@ -107,7 +107,7 @@ def perform_optimade_query(  # pylint: disable=too-many-arguments,too-many-branc
         base_url + endpoint[1:] if base_url.endswith("/") else base_url + endpoint
     )
 
-    if filter is not None:
+    if filter:
         if isinstance(filter, dict):
             pass
         elif isinstance(filter, str):
@@ -370,24 +370,36 @@ def get_versioned_base_url(  # pylint: disable=too-many-branches
     return ""
 
 
-def get_list_of_valid_providers() -> List[Tuple[str, LinksResourceAttributes]]:
+def get_list_of_valid_providers() -> Tuple[
+    List[Tuple[str, LinksResourceAttributes]], List[str]
+]:
     """Get curated list of database providers
 
     Return formatted list of tuples to use with a dropdown-widget.
     """
     providers = fetch_providers()
     res = []
+    invalid_providers = []
 
     for entry in providers:
         provider = LinksResource(**entry)
 
-        # Skip if "exmpl"
-        if provider.id == "exmpl":
-            LOGGER.debug("Skipping example provider.")
+        # Skip if "exmpl", "optimade" or "aiida"
+        if provider.id in ["exmpl", "optimade", "aiida"]:
+            LOGGER.debug("Skipping provider: %s", provider)
             continue
 
         attributes = provider.attributes
 
+        # NOTE: Temporarily disable providers NOT properly satisfying the OPTIMADE specification
+        # Follow issue #206: https://github.com/CasperWA/voila-optimade-client/issues/206
+        # For omdb: Follow issue #246: https://github.com/CasperWA/voila-optimade-client/issues/246
+        temp_disable_providers = ["cod", "tcod", "nmd", "omdb", "oqmd"]
+        if provider.id in temp_disable_providers:
+            LOGGER.debug("Temporarily disabling provider: %s", str(provider))
+            invalid_providers.append((attributes.name, attributes))
+            continue
+
         # Skip if not an 'external' link_type database
         if attributes.link_type != LinkType.EXTERNAL:
             LOGGER.debug(
@@ -398,9 +410,10 @@ def get_list_of_valid_providers() -> List[Tuple[str, LinksResourceAttributes]]:
             )
             continue
 
-        # Skip if there is no base URL
+        # Disable if there is no base URL
         if attributes.base_url is None:
             LOGGER.debug("Base URL found to be None for provider: %s", str(provider))
+            invalid_providers.append((attributes.name, attributes))
             continue
 
         versioned_base_url = get_versioned_base_url(attributes.base_url)
@@ -411,11 +424,12 @@ def get_list_of_valid_providers() -> List[Tuple[str, LinksResourceAttributes]]:
             LOGGER.debug(
                 "Could not determine versioned base URL for provider: %s", str(provider)
             )
+            invalid_providers.append((attributes.name, attributes))
             continue
 
         res.append((attributes.name, attributes))
 
-    return res
+    return res + invalid_providers, [name for name, _ in invalid_providers]
 
 
 def validate_api_version(version: str, raise_on_fail: bool = True) -> str:
@@ -444,55 +458,36 @@ def validate_api_version(version: str, raise_on_fail: bool = True) -> str:
     return ""
 
 
-def get_structures_schema(base_url: str) -> dict:
-    """Retrieve provider's /structures endpoint schema"""
+def get_entry_endpoint_schema(base_url: str, endpoint: str = None) -> dict:
+    """Retrieve provider's entry endpoint schema (default: /structures)."""
     result = {}
 
-    endpoint = "/info/structures"
-    url_path = (
-        base_url + endpoint[1:] if base_url.endswith("/") else base_url + endpoint
-    )
+    endpoint = endpoint if endpoint is not None else "structures"
+    endpoint = f"/info/{endpoint.strip('/')}"
 
-    try:
-        response = SESSION.get(url_path, timeout=TIMEOUT_SECONDS)
-        if response.from_cache:
-            LOGGER.debug("Request to %s was taken from cache !", url_path)
-    except (
-        requests.exceptions.ConnectTimeout,
-        requests.exceptions.ConnectionError,
-        requests.exceptions.ReadTimeout,
-    ) as exc:
-        return {
-            "errors": [
-                {
-                    "detail": (
-                        f"CLIENT: Connection error or timeout.\nURL: {url_path}\n"
-                        f"Exception: {exc!r}"
-                    )
-                }
-            ]
-        }
-    else:
-        if response.status_code != 200:
-            return {
-                "errors": [
-                    {
-                        "detail": f"CLIENT: Not a successful 200 response.\nURL: {url_path}",
-                        "status": response.status_code,
-                    }
-                ]
-            }
-
-        properties = response.get("data", {}).get("properties", {})
-        output_fields_by_json = response.get("output_fields_by_format", {}).get(
-            "json", []
+    response = perform_optimade_query(endpoint=endpoint, base_url=base_url)
+    msg, _ = handle_errors(response)
+    if msg:
+        LOGGER.error(
+            "Could not retrieve information about entry-endpoint %r.\n  Message: %r\n  Response:"
+            "\n%s",
+            endpoint[len("/info/") :],
+            msg,
+            response,
         )
-        for field in output_fields_by_json:
-            if field in properties:
-                result[field] = properties[field]
-
         return result
 
+    return response.get("data", {}).get("properties", {})
+
+
+def get_sortable_fields(base_url: str, endpoint: str = None) -> List[str]:
+    """Retrieve sortable fields for entry endpoint (default: /structures)."""
+    endpoint = endpoint if endpoint is not None else "structures"
+
+    schema = get_entry_endpoint_schema(base_url, endpoint)
+
+    return [field for field in schema if schema[field].get("sortable", False)]
+
 
 def handle_errors(response: dict) -> Tuple[str, set]:
     """Handle any errors"""
